@@ -714,7 +714,7 @@ class GeoTimeClassify:
 
                 return {"Category": "ISO2"}
             else:
-                return {"Category": "Unknown code"}
+                return {"Category": "Unknown Code"}
 
         def continent_f(values):
             print("start continent lookup")
@@ -806,7 +806,7 @@ class GeoTimeClassify:
 
             if np.count_nonzero(bool_array) >= (len(values) * 0.85):
 
-                return {"Category": "Boolian"}
+                return {"Category": "Boolean"}
             else:
                 return {"Category": "None"}
 
@@ -823,7 +823,7 @@ class GeoTimeClassify:
 
             if np.count_nonzero(bool_array) >= (len(values) * .85):
 
-                return {'Category': 'Boolian'}
+                return {'Category': 'Boolean'}
             else:
                 return {'Category': 'None'}
 
@@ -913,7 +913,7 @@ class GeoTimeClassify:
                     "Category": "Date",
                     "Format": "iso8601",
                     "Parser": "Util",
-                    "DayFirst": dayFirst,
+                    "DayFirst": dayFirst
                 }
             else:
                 return {"Category": "Unknown Date Format"}
@@ -925,7 +925,7 @@ class GeoTimeClassify:
                     "Category": "Date",
                     "Format": "MM-dd-y",
                     "Parser": "Util",
-                    "DayFirst": dayFirst,
+                    "DayFirst": dayFirst
                 }
             else:
                 return {"Category": "Unknown Date"}
@@ -937,7 +937,7 @@ class GeoTimeClassify:
                     "Category": "Date",
                     "Format": "MM-dd-y",
                     "Parser": "Util",
-                    "DayFirst": dayFirst,
+                    "DayFirst": dayFirst
                 }
             else:
                 return {"Category": "Unknown Date"}
